@@ -3,7 +3,7 @@ package Catalyst::Authentication::Store::LDAP;
 use strict;
 use warnings;
 
-our $VERSION = '1.016';
+our $VERSION = '1.017';
 
 use Catalyst::Authentication::Store::LDAP::Backend;
 
@@ -229,7 +229,7 @@ as identifier for the user.
 
 =head2 user_search_options
 
-This takes a hashref.  It will append it's values to the call to
+This takes a hashref.  It will append its values to the call to
 L<Net::LDAP>'s "search" method during the initial user lookup.  See
 L<Net::LDAP> for valid options.
 
@@ -297,7 +297,7 @@ If this is set to "dn", we will use the User Objects DN.
 
 =head2 role_search_options
 
-This takes a hashref.  It will append it's values to the call to
+This takes a hashref.  It will append its values to the call to
 L<Net::LDAP>'s "search" method during the user's role lookup.  See
 L<Net::LDAP> for valid options.
 
@@ -334,7 +334,7 @@ Store the user object and its roles in the session and never look it up in
 the store after login.
 
 B<NOTE:> It's recommended to limit the user attributes fetched from LDAP
-using L<user_search_options> / attrs to not exhaust the session store.
+using L</user_search_options> / C<attrs> to not exhaust the session store.
 
 =back
 
